package cn.estsh.i3plus.core.apiservice.controller.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysLogSystemService;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SysLogSystem;
import cn.estsh.impp.framework.base.controller.CoreBaseController;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description : 系统日志服务
 * @Reference :
 * @Author : yunhao
 * @Date : 2018-10-25 10:50
 * @Modify :
 **/
@RestController
@Api(description = "系统日志服务")
@RequestMapping(CoreBaseController.BASE_URL +"/sys-log-system")
public class SysLogSystemController extends CoreBaseController{
    public static final Logger LOGGER = LoggerFactory.getLogger(SysLogSystemController.class);

    @Autowired
    private ISysLogSystemService logSystemService;


    @PostMapping(value = "/insert")
    @ApiOperation(value="新增系统日志",notes = "新增系统日志")
    public ResultBean insertSysLogSystem(SysLogSystem logSystem) {
        try {
            logSystemService.insertSysLogSystem(logSystem);
            return ResultBean.success("添加成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @DeleteMapping(value = "/delete")
    @ApiOperation(value = "删除系统日志",notes = "删除系统日志")
    public ResultBean deleteSysLogSystemById(String id) {
        try {
            // 条件校验
            ValidatorBean.checkNotNull(id,"id不能为空");

            logSystemService.deleteSysLogSystemById(Long.parseLong(id));
            return ResultBean.success("删除成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping(value = "/list")
    @ApiOperation(value = "查询全部系统日志",notes = "查询全部系统日志")
    public ResultBean findSysLogSystemAll(){
        try {
            List<SysLogSystem> logSystemList = logSystemService.listSysLogSystem();
            return ResultBean.success("查询成功").setResultList(logSystemList).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping(value = "/get")
    @ApiOperation(value = "根据id查询系统日志",notes = "根据id查询系统日志")
    public ResultBean getSysLogSystemById(String id){
        try {
            SysLogSystem logSystem = logSystemService.getSysLogSystemById(Long.parseLong(id));
            return ResultBean.success("查询成功").setResultObject(logSystem).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    /**
     * 系统日志分页复杂查询
     * @param logSystem
     * @param pager
     * @return
     */
    @GetMapping("/query")
    @ApiOperation(value = "系统日志分页复杂查询",notes = "系统日志分页复杂查询")
    public ResultBean querySysLogSystemByPager(SysLogSystem logSystem, Pager pager){
        try {
            ListPager logSystemList = logSystemService.querySysLogSystemByPager(logSystem, pager);
            return ResultBean.success("查询成功").setListPager(logSystemList).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }
}
